@@ -1,23 +1,25 @@
 /*
- 
+
 Copyright (C) 2006 NTT DATA Corporation
- 
+
 This program is free software; you can redistribute it and/or
-Modify it under the terms of the GNU General Public License 
+Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.
- 
+
 This program is distributed in the hope that it will be
-useful, but WITHOUT ANY WARRANTY; without even the implied 
-warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+useful, but WITHOUT ANY WARRANTY; without even the implied
+warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 PURPOSE.  See the GNU General Public License for more details.
- 
-*/
+
+ */
 
 package com.clustercontrol.collectiverun.bean;
 
 import java.util.ArrayList;
 import java.util.List;
 
+import javax.xml.bind.annotation.XmlType;
+
 
 /**
  * 一括制御のコマンド情報を保持するクラスです。<BR>
@@ -27,21 +29,25 @@ import java.util.List;
  * @version 2.1.0
  * @since 2.1.0
  */
+@XmlType(namespace = "http://collectiverun.ws.clustercontrol.com")
 public class CommandInfo extends ItemInfo {
 	private static final long serialVersionUID = -7480505938284610080L;
 
 	/** コマンドID */
-	protected String id;
+	private String id;
 
 	/** コマンド種別 */
-	protected int commandType;
-	
+	private Integer commandType = new Integer(0);
+
 	/** コマンド */
-	protected String command;
-	
+	private String command;
+
+	/** コマンド種別ID */
+	private String commandTypeId;
+
 	/** 終了状態 */
-	protected List<EndStatusInfo> endStatus;
-	
+	private List<EndStatusInfo> endStatus;
+
 	/**
 	 * @return
 	 */
@@ -57,9 +63,9 @@ public class CommandInfo extends ItemInfo {
 	}
 
 	/**
-     * @return
-     */
-    public String getCommand() {
+	 * @return
+	 */
+	public String getCommand() {
 		return command;
 	}
 
@@ -73,17 +79,31 @@ public class CommandInfo extends ItemInfo {
 	/**
 	 * @return
 	 */
-	public int getCommandType() {
+	public Integer getCommandType() {
 		return commandType;
 	}
 
 	/**
 	 * @param commandType
 	 */
-	public void setCommandType(int commandType) {
+	public void setCommandType(Integer commandType) {
 		this.commandType = commandType;
 	}
 
+	/**
+	 * @return
+	 */
+	public String getCommandTypeId() {
+		return commandTypeId;
+	}
+
+	/**
+	 * @param command
+	 */
+	public void setCommandTypeId(String commandTypeId) {
+		this.commandTypeId = commandTypeId;
+	}
+
 	/**
 	 * @return
 	 */
@@ -99,28 +119,28 @@ public class CommandInfo extends ItemInfo {
 	}
 
 	/* (non-Javadoc)
-     * @see java.lang.Object#clone()
-     * @since 2.1.0
-     */
+	 * @see java.lang.Object#clone()
+	 * @since 2.1.0
+	 */
 	@Override
 	public Object clone() {
-        CommandInfo clone = (CommandInfo)super.clone();
-        
-        clone.setId(this.getId());
-        clone.setCommandType(this.getCommandType());
-        clone.setCommand(this.getCommand());
-        
-        ArrayList<EndStatusInfo> cloneList = new ArrayList<EndStatusInfo>();
-        if(this.getEndStatus() != null && this.getEndStatus() instanceof ArrayList){
-        	for(int i = 0; i < this.getEndStatus().size(); i++){
-        		Object source = this.getEndStatus().get(i);
-        		if(source != null && source instanceof EndStatusInfo){
-        			cloneList.add((EndStatusInfo)((EndStatusInfo)source).clone());
-        		}
-        	}
-        }
-        clone.setEndStatus(cloneList);
-        
-        return clone;
-    }
+		CommandInfo clone = (CommandInfo)super.clone();
+
+		clone.setId(this.getId());
+		clone.setCommandType(this.getCommandType());
+		clone.setCommand(this.getCommand());
+
+		ArrayList<EndStatusInfo> cloneList = new ArrayList<EndStatusInfo>();
+		if(this.getEndStatus() != null && this.getEndStatus() instanceof ArrayList){
+			for(int i = 0; i < this.getEndStatus().size(); i++){
+				Object source = this.getEndStatus().get(i);
+				if(source != null && source instanceof EndStatusInfo){
+					cloneList.add((EndStatusInfo)((EndStatusInfo)source).clone());
+				}
+			}
+		}
+		clone.setEndStatus(cloneList);
+
+		return clone;
+	}
 }
\ No newline at end of file
