@@ -27,30 +27,25 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.concurrent.ConcurrentHashMap;
 
-import javax.ejb.CreateException;
-import javax.ejb.FinderException;
-import javax.jms.JMSException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.fault.FacilityNotFound;
 import com.clustercontrol.fault.HinemosUnknown;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.hinemosagent.bean.AgentInfo;
 import com.clustercontrol.hinemosagent.bean.TopicInfo;
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.commons.util.HinemosProperties;
-import com.clustercontrol.commons.util.SendQueue;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoLocal;
-import com.clustercontrol.monitor.run.ejb.entity.MonitorInfoUtil;
+import com.clustercontrol.monitor.run.model.MonitorInfoEntity;
+import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.notify.bean.OutputBasicInfo;
-import com.clustercontrol.notify.bean.QueueConstant;
+import com.clustercontrol.notify.factory.NotifyEventTaskFactory;
+import com.clustercontrol.plugin.impl.AsyncWorkerPlugin;
 import com.clustercontrol.repository.bean.NodeInfo;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerLocal;
-import com.clustercontrol.repository.ejb.session.RepositoryControllerUtil;
 import com.clustercontrol.repository.factory.FacilitySelector;
 import com.clustercontrol.repository.factory.NodeProperty;
+import com.clustercontrol.repository.session.RepositoryControllerBean;
 import com.clustercontrol.util.Messages;
 
 
@@ -61,16 +56,14 @@ public class AgentConnectUtil {
 	// synchronized用のオブジェクト
 	private static Object topicObject = new Object();
 
-	private static SendQueue m_queueInternal;
-
 	// 接続しているエージェントのリスト
 	private static ConcurrentHashMap<String, AgentInfo> agentMap =
-		new ConcurrentHashMap<String, AgentInfo>();
+			new ConcurrentHashMap<String, AgentInfo>();
 
 	// 接続しているエージェントのライブラリのMD5
 	// ConcurrentHashMap<facilityId, HashMap<filename, md5>>
 	private static ConcurrentHashMap<String, HashMap<String, String>> agentLibMd5 =
-		new ConcurrentHashMap<String, HashMap<String, String>>();
+			new ConcurrentHashMap<String, HashMap<String, String>>();
 
 	/**
 	 * TODO
@@ -80,7 +73,7 @@ public class AgentConnectUtil {
 	 * データが損失してしまう。
 	 */
 	private static ConcurrentHashMap<String, ArrayList<TopicInfo>> topicMap =
-		new ConcurrentHashMap<String, ArrayList<TopicInfo>> ();
+			new ConcurrentHashMap<String, ArrayList<TopicInfo>> ();
 
 	/**
 	 * [Topic] エージェントにTopicを送る場合はこのメソッドを利用する。
@@ -134,7 +127,7 @@ public class AgentConnectUtil {
 		} else {
 			infoList.add(info);
 			if (infoList.size() > 10) {
-				m_log.warn("subSetTopic(): topicList is too large : size=" +
+				m_log.info("subSetTopic(): topicList is too large : size=" +
 						infoList.size());
 			}
 		}
@@ -162,7 +155,7 @@ public class AgentConnectUtil {
 				if (topicInfo.isValid()) {
 					ret.add(topicInfo);
 				} else {
-					m_log.warn("topic is too old : " + topicInfo.toString());
+					m_log.info("topic is too old : " + topicInfo.toString());
 				}
 			}
 			if (tmpInfoList != null) {
@@ -178,43 +171,39 @@ public class AgentConnectUtil {
 	 */
 	private static void awakeAgent(String facilityId) {
 		String ipAddress = "";
+		Integer port = 24005;
 		m_log.debug("awakeAgent facilityId=" + facilityId);
 		try {
-			RepositoryControllerLocal local;
-			local = RepositoryControllerUtil.getLocalHome().create();
-			ipAddress = local.getNode(facilityId).getAvailableIpAddress();
-		} catch (CreateException e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
-			return;
-		} catch (NamingException e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
-			return;
+			NodeInfo info = NodeProperty.getProperty(facilityId);
+			ipAddress = info.getAvailableIpAddress();
+			port = info.getAgentAwakePort();
 		} catch (FacilityNotFound e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			return;
+		} catch (Exception e) {
+			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			return;
 		}
 		m_log.debug("awakeAgent ipaddress=" + ipAddress);
 
 		final int BUFSIZE = 1;
-		final int PORT = 24005;
 		byte[] buf = new byte[BUFSIZE];
 		buf[0] = 1;
 		InetAddress sAddr;
 		try {
 			sAddr = InetAddress.getByName(ipAddress);
 		} catch (UnknownHostException e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 			return;
 		}
-		DatagramPacket sendPacket = new DatagramPacket(buf, BUFSIZE, sAddr, PORT);
+		DatagramPacket sendPacket = new DatagramPacket(buf, BUFSIZE, sAddr, port);
 		DatagramSocket soc = null;
 		try {
 			soc = new DatagramSocket();
 			soc.send(sendPacket);
 		} catch (SocketException e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		} catch (IOException e) {
-			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage());
+			m_log.warn("awakeAgent " + e.getClass().getSimpleName() + ", " + e.getMessage(), e);
 		} finally {
 			if (soc != null) {
 				soc.close();
@@ -223,6 +212,9 @@ public class AgentConnectUtil {
 	}
 
 	private static void printRunInstructionInfo (String facilityId, ArrayList<TopicInfo> topicInfoList) {
+		if (!m_log.isDebugEnabled()) {
+			return;
+		}
 		String str = "";
 		if (topicInfoList == null) {
 			m_log.debug("printRunInstructionInfo JobOrder : " + facilityId + ", infoList is null");
@@ -231,7 +223,7 @@ public class AgentConnectUtil {
 		for (TopicInfo topicInfo : topicInfoList) {
 			if (topicInfo.getRunInstructionInfo() != null) {
 				str += topicInfo.getRunInstructionInfo().getJobId() + ", "
-				+ topicInfo.getRunInstructionInfo().getSessionId() + ", ";
+						+ topicInfo.getRunInstructionInfo().getSessionId() + ", ";
 			}
 		}
 		m_log.debug("printRunInstructionInfo JobOrder : " + facilityId + ", " + str);
@@ -245,7 +237,7 @@ public class AgentConnectUtil {
 	public static void putAgentMap (AgentInfo agentInfo) {
 		String facilityId = agentInfo.getFacilityId();
 		if (facilityId == null) {
-			m_log.warn("putAgentMap facilityId=null");
+			m_log.info("putAgentMap facilityId=null");
 			return;
 		}
 		agentInfo.refreshLastLogin();
@@ -254,7 +246,7 @@ public class AgentConnectUtil {
 		if(cacheInfo == null) {
 			m_log.info("new agent appeared : " + agentInfo);
 			if (!facilityId.equals(agentInfo.getFacilityId())){
-				m_log.error("facilityId=" + facilityId + ", f2=" + agentInfo.getFacilityId());
+				m_log.info("facilityId=" + facilityId + ", f2=" + agentInfo.getFacilityId());
 			}
 			agentMap.put(facilityId, agentInfo.clone());
 			return;
@@ -289,13 +281,13 @@ public class AgentConnectUtil {
 				facilityIdList.add(facilityId);
 				sendMessageLocal(outputBasicInfo, facilityIdList);
 			} catch (HinemosUnknown e) {
-				m_log.error("pubAgentMap " + e.getClass().getSimpleName() + e.getMessage());
+				m_log.info("pubAgentMap " + e.getClass().getSimpleName() + e.getMessage());
 			} catch (FacilityNotFound e) {
-				m_log.error("pubAgentMap " + e.getClass().getSimpleName() + e.getMessage());
+				m_log.info("pubAgentMap " + e.getClass().getSimpleName() + e.getMessage());
 			}
 			if (!facilityId.equals(agentInfo.getFacilityId())){
 				// ここは通らないはず。
-				m_log.error("facilityId=" + facilityId + ", f2=" + agentInfo.getFacilityId());
+				m_log.info("facilityId=" + facilityId + ", f2=" + agentInfo.getFacilityId());
 			}
 			agentMap.put(facilityId, agentInfo.clone());
 		}
@@ -392,110 +384,108 @@ public class AgentConnectUtil {
 	//////////////////////////////////
 	public static void sendMessageLocal(OutputBasicInfo outputBasicInfo,
 			ArrayList<String> facilityIdList)
-	throws HinemosUnknown, FacilityNotFound {
-
-		if (m_queueInternal == null) {
-			try {
-				m_queueInternal = new SendQueue(QueueConstant.QUEUE_NAME_EVENT);
-			} catch (NamingException e) {
-				m_log.error(e,e);
-				throw new HinemosUnknown(e.getMessage(),e);
-			} catch (JMSException e) {
-				m_log.error(e,e);
-				throw new HinemosUnknown(e.getMessage(),e);
-			}
-		}
+					throws HinemosUnknown, FacilityNotFound {
 		// 監視情報を取得
 		ArrayList<String> facilityList = null;
 		try {
-			MonitorInfoLocal localMonitor = MonitorInfoUtil.getLocalHome().findByPrimaryKey(outputBasicInfo.getMonitorId());
-			String monitorFacilityId = localMonitor.getFacilityId();
-			facilityList = FacilitySelector.getFacilityIdList(monitorFacilityId, 0, false);
-		} catch (FinderException e) {
-			m_log.warn(e.getMessage() + " (" + outputBasicInfo.getMonitorId() + ")",e);
-		} catch (NamingException e) {
-			m_log.error(e.getMessage(),e);
+			MonitorInfoEntity entity = QueryUtil.getMonitorInfoPK_NONE(outputBasicInfo.getMonitorId());
+			String monitorFacilityId = entity.getFacilityId();
+			facilityList = FacilitySelector.getFacilityIdList(monitorFacilityId, entity.getOwnerRoleId(), 0, false, false);
+		} catch (MonitorNotFound e) {
+			m_log.warn(e.getMessage() + " (" + outputBasicInfo.getMonitorId() + ")", e);
 		}
 		for (String facilityId : facilityIdList) {
 			if (facilityList != null && !facilityList.contains(facilityId)) {
 				m_log.debug("not match facilityId(" + facilityId + ")");
 				continue;
 			}
+			String scopeText = "";
 			try {
-				RepositoryControllerLocal local;
-				try {
-					local = RepositoryControllerUtil.getLocalHome().create();
-				} catch (CreateException e) {
-					m_log.error(e,e);
-					throw new HinemosUnknown(e.getMessage(),e);
-				} catch (NamingException e) {
-					m_log.error(e,e);
-					throw new HinemosUnknown(e.getMessage(),e);
-				}
-				if (local == null) {
-					m_log.error("RepositoryControllerLocal is null");
-					return;
-				}
-				String scopeText = "";
-				try {
-					NodeInfo nodeInfo = local.getNode(facilityId);
-					scopeText = nodeInfo.getFacilityName();
-				} catch (FacilityNotFound e) {
-					throw e;
-				}
-				outputBasicInfo.setFacilityId(facilityId);
-				outputBasicInfo.setScopeText(scopeText);
-				m_queueInternal.put(outputBasicInfo);
-			} catch (JMSException e) {
-				m_log.error(e,e);
-				throw new HinemosUnknown(e.getMessage(),e);
+				NodeInfo nodeInfo = new RepositoryControllerBean().getNode(facilityId);
+				scopeText = nodeInfo.getFacilityName();
+			} catch (FacilityNotFound e) {
+				throw e;
 			}
+			// 通知出力情報をディープコピーする（AsyncWorkerPlugin.addTaskのため）
+			OutputBasicInfo clonedInfo = outputBasicInfo.clone();
+			clonedInfo.setFacilityId(facilityId);
+			clonedInfo.setScopeText(scopeText);
+			AsyncWorkerPlugin.addTask(NotifyEventTaskFactory.class.getSimpleName(), clonedInfo, false);
 		}
 	}
-	
+
 	/**
-	 * エージェントにマネージャのIPを送信する。
-	 * エージェントとTCPセッションが確立できた場合、trueを返す。
+	 * common.agent.discovery.pingport で記載されたポートに対しマネージャのIPを送信する。
+	 *  エージェントとTCPセッションが確立できた場合、trueを返す。
+	 *  ポート番号が無効な場合は何も実施せずにfalseを返す。
+	 * 
 	 * @param facilityId
 	 * @return
 	 * @throws UnknownHostException
-	 * @throws IOException 
+	 * @throws IOException
 	 */
-	public static boolean sendManagerIp(String facilityId) throws UnknownHostException, IOException{
-		int servPort = 24005;
+	public static boolean sendManagerDiscoveryInfo(String facilityId)
+			throws UnknownHostException, IOException {
 		String managerIpAddr = "";
 		boolean successFlag = true;
 		String agentIpAddr = "";
+		int pingPort; 
 		
-		try{
-			managerIpAddr = HinemosProperties.getProperty("agent.connection.ipaddres", InetAddress.getLocalHost().getHostAddress());
-		} catch (UnknownHostException e){
+		// 接続先ポートの決定（プロパティファイルから読み込み、正しくないポートレンジの場合には何も実施せず終了する
+		{
+			int defaultPingPort = 24005;
+			String pingPortStr = HinemosProperties.getProperty("common.agent.discovery.pingport", Integer.toString(defaultPingPort));
+			pingPort = Integer.valueOf(pingPortStr);
+			if (pingPort < 1 || pingPort > 65535) {
+				return false;
+			}
+		}
+		// エージェントが接続するためのマネージャのIPを調べる
+		try {
+			// DNS名接続の場合(agent.connection.dnsnameに文字列が指定) Hinemos ver 4.0.2以降対応
+			managerIpAddr = HinemosProperties.getProperty("agent.connection.dnsname","");
+			
+			// IPアドレス接続の場合(agent.connection.dnsnameが未指定)
+			if(managerIpAddr == null || "".equals(managerIpAddr)){
+				managerIpAddr = HinemosProperties.getProperty(
+						"agent.connection.ipaddres", InetAddress.getLocalHost()
+						.getHostAddress());
+			}
+		} catch (UnknownHostException e) {
 			throw e;
 		}
-		
+
+		// FIXME 本関数内の処理では通信のタイムアウトなどを設けていないため、異常な応答などが返った場合に無限待ちとなる可能性がある
 		Socket socket = null;
 		InputStream is = null;
 		try {
-			String sendData = "managerIp=" + managerIpAddr + ",agentFacilityId=" + facilityId;
-			byte[] data = sendData.getBytes();
+			String sendDataStr = "managerIp=" + managerIpAddr + ",agentFacilityId=" + facilityId;
+			byte[] data = sendDataStr.getBytes();
 			byte[] msg = new byte[data.length];
-			agentIpAddr = NodeProperty.getProperty(facilityId).getAvailableIpAddress();
-			socket = new Socket(agentIpAddr, servPort);
+			agentIpAddr = NodeProperty.getProperty(facilityId)
+					.getAvailableIpAddress();
 			
-			m_log.info("established the connection to the hinemos agent server at " + agentIpAddr);
+			m_log.info("trying to establish connection to hinemos agent server at "
+					+ agentIpAddr + ":" + pingPort);
 			
+			socket = new Socket(agentIpAddr, pingPort);
+
+			m_log.info("established the connection to the hinemos agent server at "
+					+ agentIpAddr);
+
 			is = socket.getInputStream();
 			OutputStream out = socket.getOutputStream();
 			out.write(data);
-			
+
 			m_log.info("sent the message： " + new String(data));
-			
+
 			// エージェントからの返信を受信
 			int totalBytesRcvd = 0;
 			int bytesRcvd;
-			
+
 			while (totalBytesRcvd < data.length) {
-				if ((bytesRcvd = is.read(msg, totalBytesRcvd, data.length - totalBytesRcvd)) == -1) {
+				if ((bytesRcvd = is.read(msg, totalBytesRcvd, data.length
+						- totalBytesRcvd)) == -1) {
 					continue;
 				}
 				totalBytesRcvd += bytesRcvd;
@@ -503,14 +493,14 @@ public class AgentConnectUtil {
 			m_log.info("received the message: " + new String(msg));
 		} catch (Exception e) {
 			successFlag = false;
-			m_log.warn("facilityId: " + facilityId + ", " + e.getMessage());
+			m_log.warn("facilityId: " + facilityId + ", " + e.getMessage(),e);
 		}
-		
+
 		try {
-			if(is != null){
+			if (is != null) {
 				is.close();
 			}
-			if(socket != null){
+			if (socket != null) {
 				socket.close();
 			}
 		} catch (IOException e) {
@@ -518,20 +508,4 @@ public class AgentConnectUtil {
 		}
 		return successFlag;
 	}
-	
-	/**
-	 * 該当のファシリティIDに対応するエージェントがマネージャと接続されているかを確認する
-	 * @param facilityId
-	 * @return
-	 */
-	public static boolean checkAgentConnection(String facilityId){
-		boolean ret = false;
-		for(AgentInfo agentInfo : AgentConnectUtil.getAgentList()){
-			if(facilityId.equals(agentInfo.getFacilityId())){
-				// 該当ファシリティIDがエージェントリストに存在する場合
-				ret = true;
-			}
-		}
-		return ret;
-	}
-}
\ No newline at end of file
+}
