@@ -967,7 +967,7 @@ public class SelectJob {
 		}
 
 		// UTILIUPDT_Sのメッセージを取得
-		if (CreateHulftJob.hulftMode) {
+		if (CreateHulftJob.isHulftMode()) {
 			try {
 				JobSessionJobEntity job = QueryUtil.getJobSessionJobPK(sessionId, jobunitId, jobId);
 				JobSessionJobEntity jobUtliupdtS = QueryUtil.getJobSessionJobPK(sessionId, jobunitId,
@@ -1193,6 +1193,44 @@ public class SelectJob {
 					}
 				}
 
+			} else if(childJobId.indexOf(CreateHulftJob.UTILIUPDT_H_SND) != -1) {
+				//"_UTLSEND"を除いたジョブIDを取得
+				String fileJobId = childJobId.replaceAll(CreateHulftJob.UTILIUPDT_H_SND, "");
+				//ファイル転送が終了の場合
+				if(childSessionJob.getStartDate() != null && childSessionJob.getEndDate() != null &&
+						(jobIdMap.get(fileJobId) == null || !jobIdMap.get(fileJobId).equals(END))){
+					if(childSessionJob.getEndStatus() == null ||
+							childSessionJob.getEndStatus() != EndStatusConstant.TYPE_NORMAL){
+						for (JobSessionNodeEntity node : childSessionJob.getJobSessionNodeEntities()) {
+							String nodeMessage = node.getMessage();
+							if (nodeMessage != null && nodeMessage.length() > 0) {
+								message.append(nodeMessage);
+								message.append(RTN);
+							}
+						}
+						jobIdMap.put(fileJobId, END);
+					}
+				}
+
+			} else if(childJobId.indexOf(CreateHulftJob.UTILIUPDT_H_RCV) != -1) {
+				//"_UTLSEND"を除いたジョブIDを取得
+				String fileJobId = childJobId.replaceAll(CreateHulftJob.UTILIUPDT_H_RCV, "");
+				//ファイル転送が終了の場合
+				if(childSessionJob.getStartDate() != null && childSessionJob.getEndDate() != null &&
+						(jobIdMap.get(fileJobId) == null || !jobIdMap.get(fileJobId).equals(END))){
+					if(childSessionJob.getEndStatus() == null ||
+							childSessionJob.getEndStatus() != EndStatusConstant.TYPE_NORMAL){
+						for (JobSessionNodeEntity node : childSessionJob.getJobSessionNodeEntities()) {
+							String nodeMessage = node.getMessage();
+							if (nodeMessage != null && nodeMessage.length() > 0) {
+								message.append(nodeMessage);
+								message.append(RTN);
+							}
+						}
+						jobIdMap.put(fileJobId, END);
+					}
+				}
+
 			} else if(childJobId.indexOf(CreateHulftJob.UTLSEND) != -1) {
 				//"_UTLSEND"を除いたジョブIDを取得
 				String fileJobId = childJobId.replaceAll(CreateHulftJob.UTLSEND, "");
