@@ -54,6 +54,7 @@ import com.clustercontrol.bean.ValidConstant;
 import com.clustercontrol.calendar.bean.CalendarInfo;
 import com.clustercontrol.calendar.session.CalendarControllerBean;
 import com.clustercontrol.commons.session.CheckFacility;
+import com.clustercontrol.commons.util.HinemosEntityManager;
 import com.clustercontrol.commons.util.HinemosSessionContext;
 import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.jobmanagement.bean.JobConstant;
@@ -354,8 +355,19 @@ public class JobControllerBean implements CheckFacility {
 
 			// old job
 			List<JobMstEntity> oldEntityList =
-					em.createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class)
+					((HinemosEntityManager)em).createNamedQuery("JobMstEntity.findByJobunitId", JobMstEntity.class, ObjectPrivilegeMode.WRITE)
 					.setParameter("jobunitId", jobunit.getData().getJobunitId()).getResultList();
+			
+			// オブジェクト権限チェック(変更対象のリストが空だった場合)
+			if(oldEntityList == null || oldEntityList.size() == 0) {
+				ObjectPrivilege_InvalidRole e = new ObjectPrivilege_InvalidRole(
+						"targetClass = " + JobMstEntity.class.getSimpleName());
+				m_log.info("replaceJobunit() : object privilege invalid. jobunitId = " 
+						+ jobunit.getData().getJobunitId());
+				
+				throw e;
+			}
+			
 			List<JobInfo> oldList = new ArrayList<JobInfo>();
 			for (JobMstEntity oldEntity : oldEntityList) {
 				JobInfo job = new JobInfo();
