@@ -34,6 +34,7 @@ import com.clustercontrol.monitor.run.util.QueryUtil;
 import com.clustercontrol.plugin.impl.SchedulerPlugin;
 import com.clustercontrol.plugin.impl.SchedulerPlugin.SchedulerType;
 import com.clustercontrol.plugin.impl.SchedulerPlugin.TriggerType;
+import com.clustercontrol.process.factory.ModifyPollingSchedule;
 import com.clustercontrol.process.util.ProcessProperties;
 
 /**
@@ -75,7 +76,7 @@ public class ModifySchedule {
 
 		for (MonitorInfoEntity entity : entityList) {
 			try {
-				updateSchedule(entity);
+				updateSchedule(entity, true);
 			} catch (Exception e) {
 				m_log.info("updateScheduleAll() scheduleJob : monitorId = " + entity.getMonitorId()
 						+ ", " + e.getClass().getSimpleName() + ", " + e.getMessage());
@@ -121,10 +122,10 @@ public class ModifySchedule {
 			m_log.warn(msg, e);
 			throw new HinemosUnknown(msg, e);
 		}
-		updateSchedule(entity);
+		updateSchedule(entity, false);
 	}
 
-	private void updateSchedule(MonitorInfoEntity entity) throws HinemosUnknown {
+	private void updateSchedule(MonitorInfoEntity entity, boolean isInitManager) throws HinemosUnknown {
 		String monitorId = entity.getMonitorId();
 		String monitorTypeId = entity.getMonitorTypeId();
 
@@ -169,10 +170,18 @@ public class ModifySchedule {
 		case CRON :
 			m_log.debug("Schedule CronTrigger. monitorId = " + monitorId + ", monitorTypeId = " + monitorTypeId);
 
-			// プロセス監視の場合は、少し遅らせる。
+			// プロセス監視の場合は、ポーリングスレッドを立ち上げ、初回の閾値判定処理を遅らせるためのディレイを設定する
 			long delay = 0;
 			if (HinemosModuleConstant.MONITOR_PROCESS.equals(monitorTypeId)) {
 				delay = ProcessProperties.getProperties().getStartSecond();
+				if (isInitManager == true) {
+					// マネージャ起動直後に限り、ポーラーを起動する。（ここで起動しない場合、初回の監視が必ず不明となる）
+					new ModifyPollingSchedule().addSchedule(monitorTypeId, monitorId, entity.getFacilityId(), entity.getRunInterval());
+					// ここで登録するポーリング処理と、その後下のほうで登録する閾値判定処理は、上記のdelay分発動タイミングがずれるはずだが、
+					// マネージャ起動直後に限っては、Quartzが有効に機能するまでに時間がかかり、Quartzが有効化後に一気に両者が動作し、
+					// 結果として不明となる可能性がある。そのため、マネージャ起動直後のみ閾値処理の開始時刻にさらに猶予をもうける。
+					delay += ProcessProperties.getProperties().getCollectInitDelaySecond();
+				}
 				m_log.debug("process delay " + delay);
 			}
 			
