@@ -270,7 +270,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorCustomInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorCustomInfoEntity getMonitorCustomInfoEntity() {
 		return this.monitorCustomInfoEntity;
 	}
@@ -281,7 +281,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorHttpInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorHttpInfoEntity getMonitorHttpInfoEntity() {
 		return this.monitorHttpInfoEntity;
 	}
@@ -312,7 +312,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional many-to-one association to MonitorNumericValueInfoEntity
-	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorNumericValueInfoEntity> getMonitorNumericValueInfoEntities() {
 		return this.monitorNumericValueInfoEntities;
 	}
@@ -323,7 +323,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorPerfInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorPerfInfoEntity getMonitorPerfInfoEntity() {
 		return this.monitorPerfInfoEntity;
 	}
@@ -334,7 +334,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorPingInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorPingInfoEntity getMonitorPingInfoEntity() {
 		return this.monitorPingInfoEntity;
 	}
@@ -345,7 +345,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorPortInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorPortInfoEntity getMonitorPortInfoEntity() {
 		return this.monitorPortInfoEntity;
 	}
@@ -356,7 +356,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorProcessInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorProcessInfoEntity getMonitorProcessInfoEntity() {
 		return this.monitorProcessInfoEntity;
 	}
@@ -367,7 +367,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorSnmpInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorSnmpInfoEntity getMonitorSnmpInfoEntity() {
 		return this.monitorSnmpInfoEntity;
 	}
@@ -378,7 +378,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorSqlInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorSqlInfoEntity getMonitorSqlInfoEntity() {
 		return this.monitorSqlInfoEntity;
 	}
@@ -389,7 +389,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorTrapInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorTrapInfoEntity getMonitorTrapInfoEntity() {
 		return this.monitorTrapInfoEntity;
 	}
@@ -400,7 +400,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorWinEventInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorWinEventInfoEntity getMonitorWinEventInfoEntity() {
 		return this.monitorWinEventInfoEntity;
 	}
@@ -410,7 +410,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	}
 
 	//bi-directional one-to-one association to MonitorWinserviceInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorWinserviceInfoEntity getMonitorWinserviceInfoEntity() {
 		return this.monitorWinserviceInfoEntity;
 	}
@@ -421,7 +421,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorLogfileInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorLogfileInfoEntity getMonitorLogfileInfoEntity() {
 		return this.monitorLogfileInfoEntity;
 	}
@@ -432,7 +432,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional one-to-one association to MonitorLogfileInfoEntity
-	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL, orphanRemoval=true)
+	@OneToOne(mappedBy="monitorInfoEntity", fetch=FetchType.LAZY, cascade=CascadeType.ALL)
 	public MonitorPluginInfoEntity getMonitorPluginInfoEntity() {
 		return this.monitorPluginInfoEntity;
 	}
@@ -442,7 +442,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 	}
 
 	//bi-directional many-to-one association to MonitorStringValueInfoEntity
-	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorStringValueInfoEntity> getMonitorStringValueInfoEntities() {
 		return this.monitorStringValueInfoEntities;
 	}
@@ -453,7 +453,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional many-to-one association to MonitorTrapValueInfoEntity
-	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorTrapValueInfoEntity> getMonitorTrapValueInfoEntities() {
 		return this.monitorTrapValueInfoEntities;
 	}
@@ -464,7 +464,7 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 
 
 	//bi-directional many-to-one association to MonitorTruthValueInfoEntity
-	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, orphanRemoval=true, fetch=FetchType.LAZY)
+	@OneToMany(mappedBy="monitorInfoEntity", cascade=CascadeType.ALL, fetch=FetchType.LAZY)
 	public List<MonitorTruthValueInfoEntity> getMonitorTruthValueInfoEntities() {
 		return this.monitorTruthValueInfoEntities;
 	}
@@ -484,12 +484,14 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		if (notDelPkList == null || notDelPkList.size() == 0) {
 			this.setMonitorNumericValueInfoEntities(null);
 		} else {
+			EntityManager em = new JpaTransactionManager().getEntityManager();
 			List<MonitorNumericValueInfoEntity> list = this.getMonitorNumericValueInfoEntities();
 			Iterator<MonitorNumericValueInfoEntity> iter = list.iterator();
 			while(iter.hasNext()) {
 				MonitorNumericValueInfoEntity entity = iter.next();
 				if (!notDelPkList.contains(entity.getId())) {
 					iter.remove();
+					em.remove(entity);
 				}
 			}
 		}
@@ -505,12 +507,14 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		if (notDelPkList == null || notDelPkList.size() == 0) {
 			this.setMonitorStringValueInfoEntities(null);
 		} else {
+			EntityManager em = new JpaTransactionManager().getEntityManager();
 			List<MonitorStringValueInfoEntity> list = this.getMonitorStringValueInfoEntities();
 			Iterator<MonitorStringValueInfoEntity> iter = list.iterator();
 			while(iter.hasNext()) {
 				MonitorStringValueInfoEntity entity = iter.next();
 				if (!notDelPkList.contains(entity.getId())) {
 					iter.remove();
+					em.remove(entity);
 				}
 			}
 		}
@@ -526,12 +530,14 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		if (notDelPkList == null || notDelPkList.size() == 0) {
 			this.setMonitorTrapValueInfoEntities(null);
 		} else {
+			EntityManager em = new JpaTransactionManager().getEntityManager();
 			List<MonitorTrapValueInfoEntity> list = this.getMonitorTrapValueInfoEntities();
 			Iterator<MonitorTrapValueInfoEntity> iter = list.iterator();
 			while(iter.hasNext()) {
 				MonitorTrapValueInfoEntity entity = iter.next();
 				if (!notDelPkList.contains(entity.getId())) {
 					iter.remove();
+					em.remove(entity);
 				}
 			}
 		}
@@ -547,12 +553,14 @@ public class MonitorInfoEntity extends ObjectPrivilegeTargetEntity {
 		if (notDelPkList == null || notDelPkList.size() == 0) {
 			this.setMonitorTruthValueInfoEntities(null);
 		} else {
+			EntityManager em = new JpaTransactionManager().getEntityManager();
 			List<MonitorTruthValueInfoEntity> list = this.getMonitorTruthValueInfoEntities();
 			Iterator<MonitorTruthValueInfoEntity> iter = list.iterator();
 			while(iter.hasNext()) {
 				MonitorTruthValueInfoEntity entity = iter.next();
 				if (!notDelPkList.contains(entity.getId())) {
 					iter.remove();
+					em.remove(entity);
 				}
 			}
 		}
