@@ -25,11 +25,13 @@ import com.clustercontrol.repository.bean.FacilityConstant;
 public class NodeElement extends FacilityElement {
 	private static final long serialVersionUID = 4185973963552875205L;
 
-	public NodeElement(String parentId, String facilityId, String facilityName, String iconImage, boolean valid) {
+	public NodeElement(String parentId, String facilityId, String facilityName, String iconImage, String ownerRoleId, boolean builtin, boolean valid) {
 		setParentId(parentId);
 		setFacilityId(facilityId);
 		setFacilityName(facilityName);
 		setIconImage(iconImage);
+		setOwnerRoleId(ownerRoleId);
+		setBuiltin(builtin);
 		setValid(valid);
 		setTypeName(FacilityConstant.TYPE_NODE_STRING);
 	}
