@@ -42,10 +42,14 @@ public class QueryUtil {
 	private static Log m_log = LogFactory.getLog( QueryUtil.class );
 
 	public static StatusInfoEntity getStatusInfoPK(StatusInfoEntityPK pk) throws MonitorNotFound, InvalidRole {
+		return getStatusInfoPK(pk, ObjectPrivilegeMode.READ);
+	}
+	
+	public static StatusInfoEntity getStatusInfoPK(StatusInfoEntityPK pk, ObjectPrivilegeMode mode) throws MonitorNotFound, InvalidRole {
 		EntityManager em = new JpaTransactionManager().getEntityManager();
 		StatusInfoEntity entity = null;
 		try {
-			entity = em.find(StatusInfoEntity.class, pk);
+			entity = ((HinemosEntityManager)em).find(StatusInfoEntity.class, pk, mode);
 			if (entity == null) {
 				MonitorNotFound e = new MonitorNotFound("StatusInfoEntity.findByPrimaryKey"
 						+ pk.toString());
@@ -67,6 +71,14 @@ public class QueryUtil {
 			String pluginId) throws MonitorNotFound, InvalidRole {
 		return getStatusInfoPK(new StatusInfoEntityPK(facilityId, monitorId, monitorDetailId, pluginId));
 	}
+	
+	public static StatusInfoEntity getStatusInfoPK(String facilityId,
+			String monitorId,
+			String monitorDetailId,
+			String pluginId,
+			ObjectPrivilegeMode mode) throws MonitorNotFound, InvalidRole {
+		return getStatusInfoPK(new StatusInfoEntityPK(facilityId, monitorId, monitorDetailId, pluginId), mode);
+	}
 
 	public static List<StatusInfoEntity> getStatusInfoByExpirationStatus(Timestamp expirationDate) {
 		EntityManager em = new JpaTransactionManager().getEntityManager();
@@ -77,10 +89,14 @@ public class QueryUtil {
 	}
 
 	public static EventLogEntity getEventLogPK(EventLogEntityPK pk) throws EventLogNotFound, InvalidRole {
+		return getEventLogPK(pk, ObjectPrivilegeMode.READ);
+	}
+
+	public static EventLogEntity getEventLogPK(EventLogEntityPK pk, ObjectPrivilegeMode mode) throws EventLogNotFound, InvalidRole {
 		EntityManager em = new JpaTransactionManager().getEntityManager();
 		EventLogEntity entity = null;
 		try {
-			entity = em.find(EventLogEntity.class, pk);
+			entity = ((HinemosEntityManager)em).find(EventLogEntity.class, pk, mode);
 			if (entity == null) {
 				EventLogNotFound e = new EventLogNotFound("EventLogEntity.findByPrimaryKey"
 						+ pk.toString());
@@ -103,6 +119,15 @@ public class QueryUtil {
 			String facilityId) throws EventLogNotFound, InvalidRole {
 		return getEventLogPK(new EventLogEntityPK(monitorId, monitorDetailId, pluginId, outputDate, facilityId));
 	}
+	
+	public static EventLogEntity getEventLogPK(String monitorId,
+			String monitorDetailId,
+			String pluginId,
+			java.util.Date outputDate,
+			String facilityId,
+			ObjectPrivilegeMode mode) throws EventLogNotFound, InvalidRole {
+		return getEventLogPK(new EventLogEntityPK(monitorId, monitorDetailId, pluginId, outputDate, facilityId), mode);
+	}
 
 	public static int updateEventLogFlgByFilter(String[] facilityIds,
 			Integer priority,
@@ -204,7 +229,7 @@ public class QueryUtil {
 			query.setParameter("generationFromDate", generationFromDate);
 		}
 		// 出力日時（至）設定
-		if(generationFromDate != null) {
+		if(generationToDate != null) {
 			query.setParameter("generationToDate", generationToDate);
 		}
 		// アプリケーション設定
