@@ -18,13 +18,11 @@ package com.clustercontrol.priority.util;
 import java.util.ArrayList;
 import java.util.HashMap;
 
-import javax.ejb.FinderException;
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
+import com.clustercontrol.fault.MonitorNotFound;
 import com.clustercontrol.priority.bean.PriorityJudgmentInfo;
 import com.clustercontrol.priority.factory.SelectPriorityJudgment;
 
@@ -38,21 +36,21 @@ public class PriorityJudgment {
 	private static Log m_log = LogFactory.getLog(PriorityJudgment.class);
 
 	protected static HashMap<String, Integer> m_patternMap = new HashMap<String, Integer>();
-	protected static final String PATTERN_1 = "1";
-	protected static final String PATTERN_2 = "2";
-	protected static final String PATTERN_3 = "3";
-	protected static final String PATTERN_4 = "4";
-	protected static final String PATTERN_5 = "5";
-	protected static final String PATTERN_6 = "6";
-	protected static final String PATTERN_7 = "7";
-	protected static final String PATTERN_8 = "8";
-	protected static final String PATTERN_9 = "9";
-	protected static final String PATTERN_10 = "10";
-	protected static final String PATTERN_11 = "11";
-	protected static final String PATTERN_12 = "12";
-	protected static final String PATTERN_13 = "13";
-	protected static final String PATTERN_14 = "14";
-	protected static final String PATTERN_15 = "15";
+	public static final String PATTERN_1 = "1";
+	public static final String PATTERN_2 = "2";
+	public static final String PATTERN_3 = "3";
+	public static final String PATTERN_4 = "4";
+	public static final String PATTERN_5 = "5";
+	public static final String PATTERN_6 = "6";
+	public static final String PATTERN_7 = "7";
+	public static final String PATTERN_8 = "8";
+	public static final String PATTERN_9 = "9";
+	public static final String PATTERN_10 = "10";
+	public static final String PATTERN_11 = "11";
+	public static final String PATTERN_12 = "12";
+	public static final String PATTERN_13 = "13";
+	public static final String PATTERN_14 = "14";
+	public static final String PATTERN_15 = "15";
 
 	static{
 		setPattern();
@@ -64,7 +62,7 @@ public class PriorityJudgment {
 	 * @param priorityList 重要度の配列(int)
 	 * @return
 	 */
-	public static Integer judgment(ArrayList priorityList) {
+	public static Integer judgment(ArrayList<Integer> priorityList) {
 		Integer priority = null;
 		boolean normal = false;
 		boolean critical = false;
@@ -72,7 +70,7 @@ public class PriorityJudgment {
 		boolean unknown = false;
 
 		for(int i =0; i < priorityList.size(); i++){
-			Integer status = (Integer)priorityList.get(i);
+			Integer status = priorityList.get(i);
 
 			if(status.intValue() == PriorityConstant.TYPE_INFO){
 				normal = true;
@@ -201,10 +199,8 @@ public class PriorityJudgment {
 		PriorityJudgmentInfo info = null;
 		try {
 			info = select.getPriorityJudgment("DEFAULT");
-		} catch (FinderException e) {
-			m_log.debug("PriorityJudgment : " + e.getMessage());
-		} catch (NamingException e) {
-			m_log.debug("PriorityJudgment : " + e.getMessage());
+		} catch (MonitorNotFound e) {
+			// 何もしない
 		}
 
 		if(info != null){
