@@ -28,8 +28,6 @@ import java.util.HashMap;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import javax.naming.NamingException;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
@@ -98,8 +96,9 @@ public class SearchNodeBySNMP {
 	 * @param mode
 	 * @param locale
 	 * @return
+	 * @throws UnknownHostException
 	 */
-	public static NodeInfo searchNode(String ipAddress, int port, String community, String version) throws NamingException, UnknownHostException{
+	public static NodeInfo searchNode(String ipAddress, int port, String community, String version) throws UnknownHostException {
 		m_log.debug("searchNode() ipAddress = " + ipAddress + ", port = " + port + ", community = " + community + ", version = " + version);
 
 		// 初期化
@@ -149,8 +148,9 @@ public class SearchNodeBySNMP {
 	 * @param mode
 	 * @param locale
 	 * @return
+	 * @throws UnknownHostException
 	 */
-	private static NodeInfo stractProperty(String ipAddress, int port, String community, String version,DataTable ret) throws NamingException, UnknownHostException {
+	private static NodeInfo stractProperty(String ipAddress, int port, String community, String version,DataTable ret) throws UnknownHostException {
 
 		NodeInfo property = new NodeInfo();
 
@@ -189,7 +189,8 @@ public class SearchNodeBySNMP {
 			//IPアドレスのバージョン
 			property.setIpAddressVersion(new Integer(ipAddressVersion));
 		} catch (UnknownHostException e) {
-			m_log.error(e.getMessage());
+			m_log.info("stractProperty() : "
+					+ e.getClass().getSimpleName() + ", " + e.getMessage());
 			throw e;
 		}
 
@@ -329,7 +330,7 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeDiskInfo(diskList);
 
 		// NICの情報を設定
@@ -481,7 +482,7 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeNetworkInterfaceInfo(nicList);
 
 		//ファイルシステム
@@ -512,9 +513,9 @@ public class SearchNodeBySNMP {
 				NodeFilesystemInfo filesystem = new NodeFilesystemInfo();
 
 				//表示名
-				filesystem.setDeviceName(convStringFilessystem(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue())));
-				//デバイス名
 				filesystem.setDeviceDisplayName(convStringFilessystem(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue())));
+				//デバイス名
+				filesystem.setDeviceName(((String)ret.getValue(getEntryKey(OID_FILESYSTEM_NAME+"."+i)).getValue()));
 				//デバイスINDEX
 				filesystem.setDeviceIndex(((Long)ret.getValue(getEntryKey(OID_FILESYSTEM_INDEX+"."+i)).getValue()).intValue());
 				//デバイス種別
@@ -535,7 +536,7 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeFilesystemInfo(filesystemList);
 
 		// CPU
@@ -573,7 +574,7 @@ public class SearchNodeBySNMP {
 				return ret;
 			}
 		}
-		);
+				);
 		property.setNodeCpuInfo(cpuList);
 
 
@@ -582,57 +583,45 @@ public class SearchNodeBySNMP {
 	}
 
 	/**
-	 * SNMPで取得できるファイルシステム名(マウント場所)から表示名に変換するメソッド。
-	 * 例：
-	 * C:\ Label: Serial Number 9058dd61
-	 * ↓
-	 * C:\
+	 * SNMPで取得したファイルシステム名が16進数だった場合に文字列に変換する
 	 */
 	private static String convStringFilessystem(String str){
+		if (str.matches("([0-9A-Fa-f]{2}\\s{0,1})+")){
+			try{
+				//strはなぜかASCIIが16進で入っている。
+				//文字が化けて入力された場合には、変換を行う。
+				char[] chars;
+				short  first;
+				short second;
+				chars=str.toCharArray();
+				StringBuffer ret = new StringBuffer();
 
-		if(str.matches("/.*")){
-			//UNIX系OSの場合
-			return str;
-		}
-		else if(str.matches("[A-Z]:\\\\.*")){
-			//Winodws系OSの場合
-			return str;
-		}
-		else{
-			//strはなぜかASCIIが16進で入っている。
-			//文字が化けて入力された場合には、変換を行う。
-			char[] chars;
-			short  first;
-			short second;
-			chars=str.toCharArray();
-			StringBuffer ret = new StringBuffer();
+				for(int i = 0; i<chars.length;){
 
-			int j=0;
+					first  = (short) (chars[i] - 48); //48は"0"なので、"1"→1の変換
+					second = (short)(chars[i+1]- 48);
 
-			for(int i = 0; i<chars.length;){
+					if(second >10){
+						//16進でA-Fの場合には、さらに7を引く
+						//10 ⇔ A(16進)なので("A"→65)を10にする、 10 = "A"(65) - "0"(48) - 7
+						second -=7;
+					}
 
+					ret.append((char) (first*16+second));
 
-				first  = (short) (chars[i] - 48); //48は"0"なので、"1"→1の変換
-				second = (short)(chars[i+1]- 48);
-
-				if(second >10){
-					//16進でA-Fの場合には、さらに7を引く
-					//10 ⇔ A(16進)なので("A"→65)を10にする、 10 = "A"(65) - "0"(48) - 7
-					second -=7;
+					i+=3;//1文字は"56 "とかで構成するので、配列2つを読んで" "をスキップ
 				}
 
-
-				//				ret[j] = (char) (first*16+second);
-				ret.append((char) (first*16+second));
-
-				i+=3;//1文字は"56 "とかで構成するので、配列2つを読んで" "をスキップ
-				j++;//リターンも文字もインクリメント
+				m_log.info("Find By SNMP : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
+				return ret.substring(0,3);
+			} catch(Exception e){
+				m_log.warn("Find By SNMP : " + e.getMessage());
+				return str;
 			}
-
-			m_log.info("Find By SNMP : Filesystem Name str = " + str + " convert to " + ret.substring(0,3));
-			return ret.substring(0,3);
 		}
-
+		else {
+			return str;
+		}
 	}
 
 
