@@ -30,6 +30,7 @@ import javax.persistence.EntityExistsException;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
+import com.clustercontrol.accesscontrol.bean.PrivilegeConstant.ObjectPrivilegeMode;
 import com.clustercontrol.collectiverun.session.CollectiveRunControllerBean;
 import com.clustercontrol.commons.util.HinemosProperties;
 import com.clustercontrol.commons.util.HinemosSessionContext;
@@ -2283,6 +2284,17 @@ public class RepositoryControllerBean {
 		}
 		for (String facilityId : facilityIdList) {
 			if (AgentConnectUtil.isValidAgent(facilityId)) {
+				
+				try {
+					// オブジェクト権限チェック
+					QueryUtil.getFacilityPK(facilityId, ObjectPrivilegeMode.EXEC);
+				} catch (InvalidRole e) {
+					// 権限がない場合は、該当のファシリティIDに対する処理は行わない
+					continue;
+				} catch (FacilityNotFound e) {
+					continue;
+				}
+				
 				m_log.info("restart() : setTopic(" + facilityId + ")");
 				AgentConnectUtil.setTopic(facilityId, topicInfo);
 				try {
