@@ -18,8 +18,8 @@ package com.clustercontrol.repository.util;
 import com.clustercontrol.repository.bean.FacilityConstant;
 import com.clustercontrol.repository.bean.FacilityInfo;
 import com.clustercontrol.repository.bean.NodeInfo;
-import com.clustercontrol.repository.ejb.entity.FacilityLocal;
-import com.clustercontrol.repository.ejb.entity.NodeLocal;
+import com.clustercontrol.repository.model.FacilityEntity;
+import com.clustercontrol.repository.model.NodeEntity;
 
 public class FacilityValidator {
 
@@ -30,15 +30,16 @@ public class FacilityValidator {
 	 * @param node ノードインスタンス
 	 * @return ノード情報
 	 */
-	public static NodeInfo nodeToArrayList(NodeLocal node) {
+	public static NodeInfo nodeToArrayList(NodeEntity node) {
 		NodeInfo nodeInfo = new NodeInfo();
-		nodeInfo.setFacilityId(node.getFacility().getFacilityId());
-		nodeInfo.setFacilityName(node.getFacility().getFacilityName());
+		nodeInfo.setFacilityId(node.getFacilityEntity() == null ? null : node.getFacilityEntity().getFacilityId());
+		nodeInfo.setFacilityName(node.getFacilityEntity() == null ? null : node.getFacilityEntity().getFacilityName());
 		nodeInfo.setIpAddressVersion(node.getIpAddressVersion());
 		nodeInfo.setIpAddressV4(node.getIpAddressV4());
 		nodeInfo.setIpAddressV6(node.getIpAddressV6());
 		nodeInfo.setPlatformFamily(node.getPlatformFamily());
-		nodeInfo.setDescription(node.getFacility().getDescription());
+		nodeInfo.setDescription(node.getFacilityEntity() == null ? null : node.getFacilityEntity().getDescription());
+		nodeInfo.setOwnerRoleId(node.getFacilityEntity() == null ? null : node.getFacilityEntity().getOwnerRoleId());
 
 		return nodeInfo;
 	}
@@ -57,9 +58,9 @@ public class FacilityValidator {
 	 * @param scope ファシリティインスタンス
 	 * @return ファシリティ情報
 	 */
-	public static FacilityInfo facilityToArrayList(FacilityLocal facility) {
+	public static FacilityInfo facilityToArrayList(FacilityEntity facility) {
 		FacilityInfo facilityInfo = new FacilityInfo();
-		if (facility.isNode()) {
+		if (FacilityUtil.isNode(facility)) {
 			facilityInfo.setFacilityType(FacilityConstant.TYPE_NODE);
 		} else {
 			facilityInfo.setFacilityType(FacilityConstant.TYPE_SCOPE);
@@ -68,7 +69,8 @@ public class FacilityValidator {
 		facilityInfo.setFacilityName(facility.getFacilityName());
 		facilityInfo.setDescription(facility.getDescription());
 		facilityInfo.setDisplaySortOrder(facility.getDisplaySortOrder());
-
+		facilityInfo.setIconImage(facility.getIconImage());
+		facilityInfo.setOwnerRoleId(facility.getOwnerRoleId());
 		return facilityInfo;
 	}
 
