@@ -30,6 +30,7 @@ import org.apache.commons.logging.LogFactory;
 
 import com.clustercontrol.bean.PriorityConstant;
 import com.clustercontrol.commons.util.HinemosProperties;
+import com.clustercontrol.commons.util.JpaTransactionManager;
 import com.clustercontrol.fault.HinemosUnknown;
 import com.clustercontrol.fault.InvalidRole;
 import com.clustercontrol.monitor.bean.EventConfirmConstant;
@@ -67,6 +68,9 @@ public class AplLogger {
 	private String m_aplName;
 
 	private static ConcurrentHashMap<String, String> m_priorityMap = null;
+	
+	private static ConcurrentHashMap<Long, Boolean> m_isInternalMode = new ConcurrentHashMap<Long, Boolean>();
+
 
 	// Syslog
 	private static boolean isSyslog = false;
@@ -264,60 +268,76 @@ public class AplLogger {
 	 * @since
 	 */
 	public void put(String monitorId, String msgID, Object[] msgArgs, String detailMsg) {
-		//現在日時取得
-		Date nowDate = new Date();
-
-		//監視項目IDとプラグインIDでイベントメッセージ（リソースファイル）から
-		String keyBase = m_pluginID + "." + monitorId + "." + msgID;
-
-		//重要度を取得
-		String keyPriority = keyBase + "." + "priority";
-
-		String priority = getString(keyPriority);
-
-		//メッセージを取得する。
-		String keyMsg = keyBase + "." + "message";
-
-		//メッセージ項目値が指定されている場合、メッセージの項目を置換
-		String msg = null;
-		if(msgArgs != null && msgArgs.length != 0){
-			msg = getString(keyMsg,msgArgs);
-		}else{
-			msg = getString(keyMsg);
+		// 既にINTERNALモードに入っている場合はこれ以上出力しない
+		Boolean isInternalMode = m_isInternalMode.get(Thread.currentThread().getId());
+		if(isInternalMode != null && isInternalMode){
+			log.debug("AplLogger has been already in INTERNAL mode. No INTERNAL logs are outputted. ");
+			return;
 		}
-
-		//    	・発生日時				:現在日時※メソッド呼び出し時に取得したもの
-		//    	・出力日時				:現在日時※イベント出力直前に取得したもの
-
-		//メッセージ情報作成
-		OutputBasicInfo output = new OutputBasicInfo();
-		output.setPluginId(m_pluginID);
-		output.setMonitorId(monitorId);
-		output.setFacilityId(INTERNAL_SCOPE);
-		output.setScopeText(INTERNAL_SCOPE_TEXT);
-		output.setApplication(m_aplName);
-		output.setMessageId(msgID);
-		output.setMessage(msg);
-		output.setMessageOrg(detailMsg == null ? "":detailMsg);
-		output.setPriority(getPriority(priority));
-		if (nowDate != null) {
-			output.setGenerationDate(nowDate.getTime());
-		}
-
-		if(isEvent && isOutput(eventLevel, getPriority(priority))){
-			putEvent(output);
-		}
-		if(isFile && isOutput(fileLevel, getPriority(priority))){
-			putFile(output);
-		}
-		if (isSyslog && isOutput(syslogLevel, getPriority(priority))){
-			putSyslog(output);
-		}
-		if (isMail && isOutput(mailLevel, getPriority(priority))) {
-			putMail(output);
-		}
-		if (isCommand && isOutput(commandLevel, getPriority(priority))) {
-			putCommand(output);
+		try{
+			// INTERNALモードに入る
+			log.debug("AplLogger INTERNAL mode start");
+			m_isInternalMode.put(Thread.currentThread().getId(), true);
+			
+			//現在日時取得
+			Date nowDate = new Date();
+	
+			//監視項目IDとプラグインIDでイベントメッセージ（リソースファイル）から
+			String keyBase = m_pluginID + "." + monitorId + "." + msgID;
+	
+			//重要度を取得
+			String keyPriority = keyBase + "." + "priority";
+	
+			String priority = getString(keyPriority);
+	
+			//メッセージを取得する。
+			String keyMsg = keyBase + "." + "message";
+	
+			//メッセージ項目値が指定されている場合、メッセージの項目を置換
+			String msg = null;
+			if(msgArgs != null && msgArgs.length != 0){
+				msg = getString(keyMsg,msgArgs);
+			}else{
+				msg = getString(keyMsg);
+			}
+	
+			//    	・発生日時				:現在日時※メソッド呼び出し時に取得したもの
+			//    	・出力日時				:現在日時※イベント出力直前に取得したもの
+	
+			//メッセージ情報作成
+			OutputBasicInfo output = new OutputBasicInfo();
+			output.setPluginId(m_pluginID);
+			output.setMonitorId(monitorId);
+			output.setFacilityId(INTERNAL_SCOPE);
+			output.setScopeText(INTERNAL_SCOPE_TEXT);
+			output.setApplication(m_aplName);
+			output.setMessageId(msgID);
+			output.setMessage(msg);
+			output.setMessageOrg(detailMsg == null ? "":detailMsg);
+			output.setPriority(getPriority(priority));
+			if (nowDate != null) {
+				output.setGenerationDate(nowDate.getTime());
+			}
+	
+			if(isEvent && isOutput(eventLevel, getPriority(priority))){
+				putEvent(output);
+			}
+			if(isFile && isOutput(fileLevel, getPriority(priority))){
+				putFile(output);
+			}
+			if (isSyslog && isOutput(syslogLevel, getPriority(priority))){
+				putSyslog(output);
+			}
+			if (isMail && isOutput(mailLevel, getPriority(priority))) {
+				putMail(output);
+			}
+			if (isCommand && isOutput(commandLevel, getPriority(priority))) {
+				putCommand(output);
+			}
+		}finally{
+			// INTERNALモードから出る
+			m_isInternalMode.put(Thread.currentThread().getId(), false);
+			log.debug("AplLogger INTERNAL mode end");
 		}
 	}
 
@@ -340,8 +360,9 @@ public class AplLogger {
 		MessageFormat syslogfmt = new MessageFormat("hinemos: {0},{1},{2},{3},{4},{5}");
 
 		// メッセージを編集
+		String priorityStr = PriorityConstant.typeToString(notifyInfo.getPriority());
 		Object[] args ={m_pluginID, m_aplName, notifyInfo.getMonitorId(), notifyInfo.getMessageId(),
-				notifyInfo.getPluginId(), notifyInfo.getMessage(), notifyInfo.getMessageOrg()};
+				priorityStr, notifyInfo.getMessage(), notifyInfo.getMessageOrg()};
 		String logmsg = syslogfmt.format(args);
 
 		// 送信時刻をセット
@@ -367,11 +388,18 @@ public class AplLogger {
 		}
 	}
 
-
-
-
 	private boolean putEvent(OutputBasicInfo notifyInfo) {
+		JpaTransactionManager jtm = null;
+		
 		try {
+			// rollbackするとイベントが出力されなくなるため、rollback用のコールバックメソッドを登録する
+			jtm = new JpaTransactionManager();
+			jtm.begin();
+			
+			jtm.addCallback(new AplLoggerPutEventAfterRollbackCallback(notifyInfo));
+			
+			jtm.commit();
+			
 			new NotifyControllerBean().insertEventLog(notifyInfo, EventConfirmConstant.TYPE_UNCONFIRMED);
 			return true;
 		} catch (HinemosUnknown e) {
@@ -380,6 +408,8 @@ public class AplLogger {
 		} catch (InvalidRole e) {
 			log.warn("fail putEvent monitorId=" + notifyInfo.getMonitorId() + ", message=" + notifyInfo.getMessage());
 			return false;
+		} finally {
+			jtm.close();
 		}
 	}
 
