@@ -31,61 +31,74 @@ HOST=`hostname`
 ########################################
 
 # INFO
-MSG_I001="${PROG}    : startup Hinemos Manager"
-MSG_I002="${PROG} -c : startup Hinemos Manager after temporally data is removed"
-MSG_I003="waiting for Hinemos Manager to start..."
-MSG_I004="Hinemos Manager started"
-MSG_I005="${PROG} -M : startup Hinemos Manager(maintenance-mode)"
+MSG_I001="waiting for Hinemos Manager to start..."
+MSG_I002="Hinemos Manager started"
 
 # WARN
 #MSG_W001="xxx"
 
 # ERROR
-MSG_E001="usage : ${PROG} [-c|-M]"
-MSG_E002="incorrect user(${USER}). please check variable HINEMOS_JBOSS_USER (${HINEMOS_HOME}/hinemos.cfg).";
-MSG_E003="failed to start Hinemos Manager"
+MSG_E001="failed to start Hinemos Manager"
 
 ########################################
 # Function
 ########################################
 
+function usage {
+	echo "usage : ${PROG} [-c|-M|-W]"
+	echo "options:"
+	echo "  -c   clean temporally queue data before startup"
+	echo "  -M   startup maintenance mode"
+	echo "  -W   do not wait until operation completes"
+}
 
 ########################################
 # SHELL
 ########################################
 
-#
 # check argument
-#
-for ARGS in "$@"
+for OPT in $@
 do
-	case ${ARGS} in
-		-c)
-			JBOSS_OPTS="${JBOSS_OPTS} -c"
-			;;
-		-M)
-			JBOSS_OPTS="${JBOSS_OPTS} -M"
-			;;
-		*)
-			Logging "${MSG_E001}"
-			Logging "${MSG_I001}"
-			Logging "${MSG_I002}"
-			Logging "${MSG_I005}"
-			exit -1
+	case ${OPT} in
+		--help)
+			usage
+			exit 0
 			;;
 	esac
 done
 
-#
-# check user executed
-#
-if [ "x"${USER} != "x"${HINEMOS_JBOSS_USER} ]
+# option check
+JVM_START_OPTS=""
+while getopts cMW OPT
+do
+	case ${OPT} in
+		c)
+			JVM_START_OPTS="${JVM_START_OPTS} -c"
+			;;
+		M)
+			JVM_START_OPTS="${JVM_START_OPTS} -M"
+			;;
+		W)
+			JVM_START_OPTS="${JVM_START_OPTS} -W"
+			;;
+		*)
+			ExitIllegalOptionErrorWithoutLogger
+			;;
+	esac
+done
+
+shift $(( $OPTIND - 1 ))
+
+if [ ! $# = 0 ]
 then
-	Logging "${MSG_E002}"
-	exit -2
+	ExitIllegalArgumentError
 fi
 
-Logging "${MSG_I003}" && echo
+# check user executed
+CheckUser ${JVM_USER}
+
+Logging "${MSG_I001}"
+echo
 
 # startup PostgreSQL
 ${HINEMOS_HOME}/bin/pg_start.sh
@@ -93,21 +106,25 @@ ${HINEMOS_HOME}/bin/pg_start.sh
 RET=$?
 if [ ${RET} -ne 0 ]
 then
-	echo && Logging "${MSG_E003}"
+	echo
+	Logging "${MSG_E001}"
 	exit ${RET}
 fi
 
-# startup JBoss
-${HINEMOS_HOME}/bin/jboss_start.sh ${JBOSS_OPTS}
+# startup JVM
+echo
+${HINEMOS_HOME}/bin/jvm_start.sh ${JVM_START_OPTS}
 
 RET=$?
 if [ ${RET} -ne 0 ]
 then
-	echo && Logging "${MSG_E003}"
+	echo
+	Logging "${MSG_E001}"
 	exit ${RET}
 fi
 
-echo && Logging "${MSG_I004}"
+echo
+Logging "${MSG_I002}"
 
 exit 0
 
