@@ -31,14 +31,7 @@ HOST=`hostname`
 ########################################
 
 # INFO
-MSG_I001="Hinemos Manager is running..."
-MSG_I002="Hinemos Manager is stopped"
-MSG_I003="  - JBoss Process ID      :"
-MSG_I004="  - PostgreSQL Process ID :"
-MSG_I005="- Starting Hinemos RDBMS Server (PostgreSQL) : "
-MSG_I006="- Starting Hinemos Application Server (JBoss) : "
-MSG_I007="- Stopping Hinemos RDBMS Server (PostgreSQL) : "
-MSG_I008="- Stopping Hinemos Application Server (JBoss) : "
+#MSG_I001="xxx"
 
 # WARN
 #MSG_W001="xxx"
@@ -54,47 +47,29 @@ MSG_I008="- Stopping Hinemos Application Server (JBoss) : "
 # show usage
 #
 function usage {
-        echo "usage : ${PROG} (no argument)"
+	echo "usage : ${PROG} (no argument)"
 }
 
-
 ########################################
 # SHELL
 ########################################
 
-#
 # check argument
-#
 for OPT in $@
 do
-        case $OPT in
-                --help)
-                        usage
-                        exit 0
-                        ;;
-        esac
+	case ${OPT} in
+		--help)
+			usage
+			exit 0
+			;;
+	esac
 done
 
-# option check
-while getopts w: OPT
-do
-        case $OPT in
-                *)
-                        ExitIllegalOptionErrorWithoutLogger
-                        ;;
-        esac
-done
-
-shift $(( $OPTIND - 1 ))
-
 if [ ! $# = 0 ]
 then
-        ExitIllegalArgumentError
+	ExitIllegalArgumentError
 fi
 
-
-#
 # main
-#
 CheckHinemosManagerStatus
 exit $?
