@@ -27,9 +27,6 @@ cd ${HINEMOS_HOME}/var/log
 #  Local Variable
 ########################################
 
-# log file path (pg_ctl -l option)
-PG_LOGFILE="${HINEMOS_HOME}/var/log/postgresql.log"
-
 # timeout [sec] (pg_ctl -t option)
 #   this variable is valid with -W option
 PG_TIMEOUT=90
@@ -39,83 +36,84 @@ PG_TIMEOUT=90
 ########################################
 
 # INFO
-MSG_I001="PostgreSQL started"
-MSG_I002="waiting for PostgreSQL to start..."
+MSG_I001="waiting for PostgreSQL startup..."
+MSG_I002="PostgreSQL started"
 
 # WARN
-#MSG_W001="xxx"
+MSG_W001="xxx"
 
 # ERROR
-MSG_E001="usage : ${PROG} [-W]"
-MSG_E002="failed to start PostgreSQL"
-MSG_E003="incorrect user ('${USER}')"
-MSG_E004="execute this script at '${HINEMOS_PG_USER}' user."
+MSG_E001="failed to start PostgreSQL"
 
 ########################################
 # Function
 ########################################
 
+function usage {
+	echo "usage : ${PROG} [-F]"
+	echo "options:"
+	echo "  -F   force immediate shutdown without process check (dependency, current status)"
+}
+
+function startup {
+	Logging "${MSG_I001}"
+	su -c ". ${HINEMOS_HOME}/hinemos.cfg && ${PG_HOME}/bin/pg_ctl start -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -l ${PG_LOGFILE}" - ${PG_USER}
+	RET=$?
+	
+	if [ ${RET} -eq 0 ]
+	then
+		Logging "${MSG_I002}"
+	else
+		Logging "${MSG_E001}"
+	fi
+	return ${RET}
+}
 
 ########################################
 # SHELL
 ########################################
 
-#
 # check argument
-#
-PG_STARTUP_WAIT="true"
-for ARGS in "$@"
+for OPT in $@
 do
-	case ${ARGS} in
-		-W)
-			PG_STARTUP_WAIT="false"
-			;;
-		*)
-			Logging "${MSG_E001}"
-			exit -1
+	case ${OPT} in
+		--help)
+			usage
+			exit 0
 			;;
 	esac
 done
 
-#
+# option check
+FORCE="false"
+while getopts F OPT
+do
+	case ${OPT} in
+		F)
+			FORCE="true"
+			;;
+		*)
+			ExitIllegalOptionErrorWithoutLogger
+			;;
+	esac
+done
+
+shift $(( $OPTIND - 1 ))
+
+if [ ! $# = 0 ]
+then
+	ExitIllegalArgumentError
+fi
+
 # check user executed
-#
-if [ "x"${USER} != "x"${HINEMOS_PG_USER} ] && [ "x"${USER} != "x"${HINEMOS_JBOSS_USER} ]
+CheckUser ${JVM_USER}
+
+if [ "x${FORCE}" != "xtrue" ]
 then
-	Logging "${MSG_E003}"
-	Logging "${MSG_E004}"
-	exit -2
+	CheckPostgreSQLProcessStopped
 fi
 
-#
 # startup PostgreSQL
-#
-Logging "${MSG_I002}"
-ABOUT_STARTUP=""
-if [ "x"${PG_STARTUP_WAIT} = "xtrue" ]
-then
-	if [ "x"${USER} = "x"${HINEMOS_PG_USER} ]
-	then
-		${PG_HOME}/bin/pg_ctl start -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -l ${PG_LOGFILE}
-	else
-		su -c "${PG_HOME}/bin/pg_ctl start -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -l ${PG_LOGFILE}" - ${HINEMOS_PG_USER}
-	fi
-else
-	ABOUT_STARTUP=" (with -W option)"
-	if [ "x"${USER} = "x"${HINEMOS_PG_USER} ]
-	then
-		${PG_HOME}/bin/pg_ctl start -s -D ${PG_DATA} -l ${PG_LOGFILE}
-	else
-		su -c "${PG_HOME}/bin/pg_ctl start -s -D ${PG_DATA} -l ${PG_LOGFILE}" - ${HINEMOS_PG_USER}
-	fi
-fi
-RET=$?
+startup
 
-if [ ${RET} -eq 0 ]
-then
-	Logging "${MSG_I001}${ABOUT_STARTUP}"
-else
-	Logging "${MSG_E002}"
-fi
-
-exit ${RET}
+exit $?
