@@ -39,93 +39,86 @@ PG_TIMEOUT=90
 ########################################
 
 # INFO
-MSG_I001="PostgreSQL stopped"
-MSG_I002="waiting for PostgreSQL to stop..."
+MSG_I001="waiting for PostgreSQL shutdown..."
+MSG_I002="PostgreSQL stopped"
 
 # WARN
 #MSG_W001="xxx"
 
 # ERROR
-MSG_E001="usage : ${PROG} [-W]"
-MSG_E002="failed to stop PostgreSQL"
-MSG_E003="incorrect user ('${USER}')"
-MSG_E004="PID file (${HINEMOS_JBOSS_PID}) exists. JBoss may be running."
-MSG_E005="execute this script at '${HINEMOS_PG_USER}' user."
+MSG_E001="failed to stop PostgreSQL"
 
 ########################################
 # Function
 ########################################
 
+function usage {
+	echo "usage : ${PROG} [-F]"
+	echo "options:"
+	echo "  -F   force immediate shutdown without process check (dependency, current status)"
+}
+
+function shutdown {
+	Logging "${MSG_I001}"
+	su -c ". ${HINEMOS_HOME}/hinemos.cfg && ${PG_HOME}/bin/pg_ctl stop -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -m ${PG_SHUTDOWN_MODE}" - ${PG_USER}
+	RET=$?
+	
+	if [ ${RET} -eq 0 ]
+	then
+		Logging "${MSG_I002} (shutdown mode : ${PG_SHUTDOWN_MODE})"
+	else
+		Logging "${MSG_E001} (shutdown mode : ${PG_SHUTDOWN_MODE})"
+	fi
+	
+	return ${RET}
+}
 
 ########################################
 # SHELL
 ########################################
 
-#
 # check argument
-#
-PG_SHUTDOWN_WAIT="true"
-for ARGS in "$@"
+for OPT in $@
 do
-	case ${ARGS} in
-		-W)
-			PG_SHUTDOWN_WAIT="false"
-			;;
-		*)
-			Logging "${MSG_E001}"
-			exit -1
+	case ${OPT} in
+		--help)
+			usage
+			exit 0
 			;;
 	esac
 done
 
-#
+# option check
+while getopts F OPT
+do
+	case ${OPT} in
+		F)
+			PG_SHUTDOWN_MODE="immediate"
+			;;
+		*)
+			ExitIllegalOptionErrorWithoutLogger
+			;;
+	esac
+done
+
+shift $(( $OPTIND - 1 ))
+
+if [ ! $# = 0 ]
+then
+	ExitIllegalArgumentError
+fi
+
 # check user executed
-#
-if [ "x"${USER} != "x"${HINEMOS_PG_USER} ] && [ "x"${USER} != "x"${HINEMOS_JBOSS_USER} ]
+CheckUser ${JVM_USER}
+
+if [ "x${PG_SHUTDOWN_MODE}" != "ximmediate" ]
 then
-	Logging "${MSG_E003}"
-	Logging "${MSG_E005}"
-	exit -2
+	# check JVM process
+	CheckJVMProcessStopped
+	CheckPostgreSQLProcessRunning
 fi
 
-#
-# check JBoss process
-#
-if [ -f ${HINEMOS_JBOSS_PID} ]
-then
-	Logging "${MSG_E004}"
-	exit -5
-fi
-
-#
 # shutdown PostgreSQL
-#
-Logging "${MSG_I002}"
-ABOUT_STARTUP=""
-if [ "x"${PG_SHUTDOWN_WAIT} = "xtrue" ]
-then
-	if [ "x"${USER} = "x"${HINEMOS_PG_USER} ]
-	then
-		${PG_HOME}/bin/pg_ctl stop -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -m ${PG_SHUTDOWN_MODE}
-	else
-		su -c "${PG_HOME}/bin/pg_ctl stop -w -t ${PG_TIMEOUT} -s -D ${PG_DATA} -m ${PG_SHUTDOWN_MODE}" - ${HINEMOS_PG_USER}
-	fi
-else
-	ABOUT_SHUTDOWN=" (with -W option)"
-	if [ "x"${USER} = "x"${HINEMOS_PG_USER} ]
-	then
-		${PG_HOME}/bin/pg_ctl stop -s -D ${PG_DATA} -m ${PG_SHUTDOWN_MODE}
-	else
-		su -c "${PG_HOME}/bin/pg_ctl stop -s -D ${PG_DATA} -m ${PG_SHUTDOWN_MODE}" - ${HINEMOS_PG_USER} 
-	fi
-fi
-RET=$?
+shutdown
 
-if [ ${RET} -eq 0 ]
-then
-	Logging "${MSG_I001}${ABOUT_SHUTDOWN}"
-else
-	Logging "${MSG_E002}"
-fi
-
-exit ${RET}
+exit $?
