@@ -99,7 +99,7 @@ EchoOK
 
 # check user executed
 Logging "${MSG_I002}" noreturn
-if [ "x"${USER} != "x"${HINEMOS_PG_USER} ]
+if [ "x"${USER} != "x"${PG_USER} ]
 then
 	EchoNG
 	exit 1
@@ -130,7 +130,7 @@ EchoOK
 
 # startup database
 Logging "${MSG_I005}" noreturn
-${HINEMOS_HOME}/bin/pg_start.sh > /dev/null 2>&1
+${PG_HOME}/bin/pg_ctl start -w -t 90 -s -D ${PG_DATA} -l ${PG_LOGFILE} > /dev/null 2>&1
 RET=$?
 if [ ${RET} -ne 0 ]
 then
@@ -154,10 +154,11 @@ EchoOK
 # initialize database schema (ant alter table for quartz version up)
 Logging "${MSG_I007}" noreturn
 ${PG_HOME}/bin/psql -q -p 24001 template1 -c "CREATE DATABASE hinemos" && \
-${PG_HOME}/bin/psql -q -p 24001 -f ${HINEMOS_HOME}/sbin/db_init/hinemos_schema_table.sql && \
-${PG_HOME}/bin/psql -q -p 24001 -f ${HINEMOS_HOME}/sbin/db_init/${LANGUAGE}_hinemos_data.sql && \
-${PG_HOME}/bin/psql -q -p 24001 -f ${HINEMOS_HOME}/sbin/db_init/hinemos_schema_constraint.sql && \
-${PG_HOME}/bin/psql -q -p 24001 -f ${HINEMOS_HOME}/sbin/db_init/hinemos_trap_events.sql
+${PG_HOME}/bin/psql -q -p 24001 --set ON_ERROR_STOP=on -f ${HINEMOS_HOME}/sbin/db_init/hinemos_pg_extension.sql
+${PG_HOME}/bin/psql -q -p 24001 --set ON_ERROR_STOP=on -f ${HINEMOS_HOME}/sbin/db_init/hinemos_schema_table.sql && \
+${PG_HOME}/bin/psql -q -p 24001 --set ON_ERROR_STOP=on -f ${HINEMOS_HOME}/sbin/db_init/${LANGUAGE}_hinemos_data.sql && \
+${PG_HOME}/bin/psql -q -p 24001 --set ON_ERROR_STOP=on -f ${HINEMOS_HOME}/sbin/db_init/hinemos_schema_constraint.sql && \
+${PG_HOME}/bin/psql -q -p 24001 --set ON_ERROR_STOP=on -f ${HINEMOS_HOME}/sbin/db_init/hinemos_trap_events.sql
 RET=$?
 if [ ${RET} -ne 0 ]
 then
@@ -187,7 +188,7 @@ EchoOK
 
 # shutdown database
 Logging "${MSG_I009}" noreturn
-${HINEMOS_HOME}/bin/pg_stop.sh > /dev/null 2>&1
+${PG_HOME}/bin/pg_ctl stop -w -t 90 -s -D ${PG_DATA} -m fast > /dev/null 2>&1
 RET=$?
 if [ ${RET} -ne 0 ]
 then
