@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) since 2006 NTT DATA Corporation
+# Copyright (C) 2013 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -15,8 +15,8 @@
 . /opt/hinemos/hinemos.cfg
 
 # User check
-if [ ! `whoami` = ${HINEMOS_JBOSS_USER} ]; then
-	echo "Please execute it by the ${HINEMOS_JBOSS_USER} user."
+if [ ! `whoami` = ${JVM_USER} ]; then
+	echo "Please execute it by the ${JVM_USER} user."
 	exit 1
 fi
 
@@ -46,13 +46,13 @@ echo "-------------------------------------------------------"
 echo "   Welcome to the Setup of the collective run function"
 echo "                     Hinemos  Version ${VERSION}"
 echo
-echo "       Copyright (C) since 2006 NTT DATA Corporation"
+echo "           Copyright (C) 2013 NTT DATA Corporation"
 echo "-------------------------------------------------------"
 
 # Making of public key for attestation of JBoss start user
 setup() {
     echo "" 
-    echo "The public key for the attestation of the ${HINEMOS_JBOSS_USER} user is made without the passphrase."
+    echo "The public key for the attestation of the ${JVM_USER} user is made without the passphrase."
     echo "Is it good? (Y/N default:Y)"
     while [ 1 ];
     do
@@ -108,7 +108,7 @@ setup() {
 entry() {
     if [ ! -e ${HOME}/.ssh/id_rsa.pub ]; then
         echo ""
-        echo "${HINEMOS_JBOSS_USER} user's public key is not made. Please make it."
+        echo "${JVM_USER} user's public key is not made. Please make it."
         return
     fi
     
@@ -116,7 +116,7 @@ entry() {
 
     echo ""
     echo ""
-    echo "${HINEMOS_JBOSS_USER} user's public key is registered in the ${REMOTE_USER} user's with node for the authorized_keys file."
+    echo "${JVM_USER} user's public key is registered in the ${REMOTE_USER} user's with node for the authorized_keys file."
 
     while [ 1 ];
     do
@@ -151,7 +151,7 @@ entry() {
 			;;
 		esac
 		
-		echo "${HINEMOS_JBOSS_USER} user's public key is set to ${ROOT_HOME}.ssh/authorized_keys."
+		echo "${JVM_USER} user's public key is set to ${ROOT_HOME}.ssh/authorized_keys."
 		echo "Is it good? (Y/N default:Y)"
 		read ANS
 		ANS=${ANS:-Y}
@@ -190,7 +190,7 @@ do
     echo ""
     echo "the Setup of the collective run function"
     echo ""
-    echo "     1) Making of public key for attestation of ${HINEMOS_JBOSS_USER} user"
+    echo "     1) Making of public key for attestation of ${JVM_USER} user"
     echo "     2) Public key registration to node for monitoring"
     echo "     9) Setup end of collective run function"
     echo ""
