@@ -26,7 +26,6 @@ HOST=`hostname`
 DBPORT=24001
 DBNAME=hinemos
 DBUSER=hinemos
-DBPASSWORD=hinemos
 
 DUMP_PATH="."
 PGDUMP_FILE_BASE="hinemos_pgdump"
@@ -40,14 +39,14 @@ DATE=`date "+%Y-%m-%d_%H%M%S"`
 # INFO
 MSG_I001="dumping data stored in Hinemos RDBMS Server (PostgreSQL)..."
 MSG_I002="   output file : "
-MSG_I101="successful in backing up data stored in Hinemos RDBMS Server (PostgreSQL)."
+MSG_I101="successful in dumping data."
 
 # WARN
 MSG_W001="output file already exists. remove it and try again."
 
 # ERROR
 MSG_E001="failed to execute pg_dump command."
-MSG_E002="failed to back up data stored in Hinemos RDBMS Server (PostgreSQL)."
+MSG_E002="failed to dump data."
 
 ########################################
 # Function
@@ -66,7 +65,7 @@ function usage {
 # dump data of PostgreSQL
 #
 function dump_postgresql {
-	ReadPostgreSQLPasswd
+	AskPostgreSQLPasswd
 	
 	DUMP_FILE="${DUMP_PATH}/${PGDUMP_FILE_BASE}.${DATE}"
 	
@@ -113,7 +112,7 @@ while getopts w: OPT
 do
 	case $OPT in
 		w)
-			PASSWD=$OPTARG
+			export PGPASSWORD=${OPTARG}
 			;;
 		*)
 			ExitIllegalOptionErrorWithoutLogger
@@ -128,10 +127,12 @@ then
 	ExitIllegalArgumentError
 fi
 
+# check user
+CheckUser ${JVM_USER}
+
 # check process
 CheckPostgreSQLProcessRunning
 
-
 # main
 dump_postgresql
 RET=$?
