@@ -443,6 +443,13 @@ ${PSQLCMD} -c "
         idx_blks_read + idx_blks_hit DESC
 " | tee -a ${SUMMARY_FILE}
 
+## txid_current
+echo "### txid_current ###" | tee -a ${SUMMARY_FILE}
+${PSQLCMD} -c "
+    SELECT
+        txid_current()
+" | tee -a ${SUMMARY_FILE}
+
 
 
 }
@@ -645,7 +652,7 @@ do
 	NUM=`expr ${NUM} + 1`
 	echo -n "getting thread dump ${NUM}/${COUNT} ... "  | tee -a ${HINEMOS_HOME}/var/log/${DUMP_INFO_FILENAME}
 	echo -n `date`  | tee -a ${HINEMOS_HOME}/var/log/${DUMP_INFO_FILENAME}
-	kill -3 `cat ${HINEMOS_HOME}/var/run/jboss.pid`
+	kill -3 `cat ${HINEMOS_HOME}/var/run/jvm.pid`
 	echo " [OK] "  | tee -a ${HINEMOS_HOME}/var/log/${DUMP_INFO_FILENAME}
 	echo -e "\n" >> ${HINEMOS_HOME}/var/log/${DUMP_INFO_FILENAME}
 
@@ -673,7 +680,7 @@ do
 
 done
 
-cp -p ${HINEMOS_HOME}/var/log/jboss_stdout.log ${HINEMOS_HOME}/var/log/${DUMP_FILENAME}
+cp -p ${HINEMOS_HOME}/var/log/jvm_stdout.log ${HINEMOS_HOME}/var/log/${DUMP_FILENAME}
 
 echo -e "\n"
 echo "### Please get this file ###"
