@@ -26,7 +26,6 @@ HOST=`hostname`
 DBPORT=24001
 DBNAME=postgres
 DBUSER=hinemos
-DBPASSWORD=hinemos
 
 ########################################
 #  Local Message
@@ -65,7 +64,7 @@ function usage {
 # restore PostgreSQL
 #
 function restore_postgresql {
-	ReadPostgreSQLPasswd
+	AskPostgreSQLPasswd
 	
 	# clear database
 	Logging "${MSG_I003}"
@@ -86,7 +85,7 @@ function restore_postgresql {
 	# restore database
 	Logging "${MSG_I001}"
 	Logging "${MSG_I002}${DUMP_FILE}"
-	MSG=`${PG_HOME}/bin/psql -p ${DBPORT} -U ${DBUSER} -d ${DBNAME} -f ${DUMP_FILE} 2>&1`
+	MSG=`${PG_HOME}/bin/psql --set ON_ERROR_STOP=on -p ${DBPORT} -U ${DBUSER} -d ${DBNAME} -f ${DUMP_FILE} 2>&1`
 	RET=$?
 	if [ ${RET} -ne 0 ]
 	then
@@ -119,7 +118,7 @@ while getopts w: OPT
 do
 	case $OPT in
 		w)
-			PASSWD=$OPTARG
+			export PGPASSWORD=${OPTARG}
 			;;
 		*)
 			ExitIllegalOptionErrorWithoutLogger
@@ -143,10 +142,9 @@ then
 fi
 
 # check process
-CheckJBossProcessStopped
+CheckJVMProcessStopped
 CheckPostgreSQLProcessRunning
 
-
 # main
 restore_postgresql
 RET=$?
